*Less Basic Python Programming* is a collection of 161 programming problems
with accompanying unit tests.
They were created with the aim of being fresh (not leaked at the time of
creation) and more difficult than similar datasets (e.g., HumanEval and MBPP).
It can serve as a drop-in replacement or enrichment of those datasets as they
are structured in an equivalent way.